@@ -1,10 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "multiple-cursors" "20260108.909"
-  "Multiple cursors for emacs."
-  '((cl-lib "0.5"))
+(define-package "multiple-cursors" "20260117.1733"
+  "Multiple cursors for Emacs."
+  '((emacs  "24.4")
+    (cl-lib "0.5"))
   :url "https://github.com/magnars/multiple-cursors.el"
-  :commit "2cd802b1f71efead5a12a3e27da34e257a47a135"
-  :revdesc "2cd802b1f71e"
+  :commit "ddd677091afc7d65ce56d11866e18aeded110ada"
+  :revdesc "ddd677091afc"
   :keywords '("editing" "cursors")
   :authors '(("Magnar Sveen" . "magnars@gmail.com"))
   :maintainers '(("Magnar Sveen" . "magnars@gmail.com")))
